'use client';

import { useState, useEffect } from 'react';
import { motion } from 'framer-motion';
import { FiPlus, FiEdit2, FiTrash2, FiBook } from 'react-icons/fi';
import { getTopics, deleteTopic } from '@/utils/firebase_utils';
import type { Topic } from '@/types/education';
import { useRouter } from 'next/navigation';

export default function TopicsPage() {
  const [topics, setTopics] = useState<Topic[]>([]);
  const [loading, setLoading] = useState(true);
  const router = useRouter();

  useEffect(() => {
    loadTopics();
  }, []);

  const loadTopics = async () => {
    try {
      setLoading(true);
      const response = await getTopics({ isActive: true });
      setTopics(response.items);
    } catch (error) {
      console.error('Error loading topics:', error);
    } finally {
      setLoading(false);
    }
  };

  const handleDelete = async (id: string) => {
    if (!window.confirm('Are you sure you want to delete this topic?')) return;
    try {
      await deleteTopic(id);
      setTopics(prev => prev.filter(topic => topic.id !== id));
    } catch (error) {
      console.error('Error deleting topic:', error);
    }
  };

  if (loading) {
    return (
      <div className="space-y-4">
        {[1, 2, 3].map((i) => (
          <div key={i} className="bg-[#1a1a1a] p-6 rounded-lg animate-pulse">
            <div className="h-6 w-48 bg-[#2a2a2a] rounded mb-2"></div>
            <div className="h-4 w-64 bg-[#2a2a2a] rounded"></div>
          </div>
        ))}
      </div>
    );
  }

  return (
    <div className="space-y-6">
      {/* Header */}
      <div className="flex justify-between items-center">
        <div>
          <h1 className="text-2xl font-bold text-white">Topics</h1>
          <p className="text-gray-400">Manage educational topics</p>
        </div>
        <motion.button
          whileHover={{ scale: 1.02 }}
          whileTap={{ scale: 0.98 }}
          onClick={() => router.push('/admin/content/topics/new')}
          className="px-4 py-2 bg-[#FF6B2B] text-white rounded-lg hover:bg-[#FF6B2B]/90 
            flex items-center space-x-2"
        >
          <FiPlus className="w-5 h-5" />
          <span>Add Topic</span>
        </motion.button>
      </div>

      {/* Topics Grid */}
      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
        {topics.map((topic, index) => (
          <motion.div
            key={topic.id}
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ delay: index * 0.1 }}
            className="bg-[#1a1a1a] rounded-lg p-6 group hover:bg-[#2a2a2a] transition-colors"
          >
            <div className="flex items-start justify-between">
              <div className="flex-1">
                <div className="flex items-center space-x-2">
                  <FiBook className="w-5 h-5 text-[#FF6B2B]" />
                  <h3 className="text-white font-semibold text-lg">{topic.name}</h3>
                </div>
                <p className="text-gray-400 text-sm mt-1">{topic.description}</p>
                <div className="flex items-center space-x-2 mt-2">
                  <span className="px-2 py-1 bg-[#FF6B2B]/10 text-[#FF6B2B] text-xs rounded-full">
                    {topic.subjectId}
                  </span>
                  <span className="px-2 py-1 bg-[#2a2a2a] text-gray-300 text-xs rounded-full">
                    Contents
                  </span>
                </div>
              </div>
              <div className="flex space-x-2 opacity-0 group-hover:opacity-100 transition-opacity">
                <motion.button
                  whileHover={{ scale: 1.1 }}
                  whileTap={{ scale: 0.9 }}
                  onClick={() => router.push(`/admin/content/topics/${topic.id}/edit`)}
                  className="p-2 bg-blue-500/10 text-blue-500 rounded-lg hover:bg-blue-500/20"
                >
                  <FiEdit2 className="w-4 h-4" />
                </motion.button>
                <motion.button
                  whileHover={{ scale: 1.1 }}
                  whileTap={{ scale: 0.9 }}
                  onClick={() => handleDelete(topic.id)}
                  className="p-2 bg-red-500/10 text-red-500 rounded-lg hover:bg-red-500/20"
                >
                  <FiTrash2 className="w-4 h-4" />
                </motion.button>
              </div>
            </div>
          </motion.div>
        ))}
      </div>

      {topics.length === 0 && (
        <div className="text-center py-12 bg-[#1a1a1a] rounded-lg">
          <p className="text-gray-400">No topics found. Add your first topic to get started.</p>
        </div>
      )}
    </div>
  );
} 